import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/goods/carmodel/saveManageCarModel")
def goods_carmodel_savemanagecarmodel(carDetailType=None, preToDepositEndTime=None, prePrice=None, sharePosters=None, price=None, preEndTime=None, carCode=None, brandName=None, modelName=None, modelId=None, modelCode=None, carName=None, depositStartTime=None, depositPriceContent=None, depositEndTime=None, carSimpleName=None, prePriceContent=None, status=None, promptDesc=None, preToDepositStartTime=None, preStartTime=None, version=None, carDetailPics=None, carDetailUrl=None, prePricePosters=None, sort=None, configCode=None, depositPrice=None, posters=None, headers=None, **kwargs):
    """
    保存车型详细信息 - Y
    up_time=1675664128

    params: carName : string : 车系名称
    params: brandName : string : 品牌名称
    params: version : string : 品牌代码
    params: carCode : string : 车系代码
    params: modelName : string : 车型名称
    params: modelCode : string : 车型代号
    params: carSimpleName : string : 车型销售名称
    params: configCode : string : 配置编码
    params: sort : number : 车型权重
    params: price : number : 基础零售价
    params: carDetailType : number : 车型详情类型 - 1:图片，2:H5连接
    params: carDetailUrl : string : 车型详情类型为2 h5跳转地址
    params: preStartTime : string : 预订开始时间
    params: preEndTime : string : 预订结束时间
    params: preToDepositStartTime : string : 预订转大定开始时间
    params: preToDepositEndTime : string : 预订转大定结束时间
    params: prePrice : number : 预订金价格
    params: prePriceContent : string : 预订权益内容
    params: depositStartTime : string : 大定开始时间
    params: depositEndTime : string : 大定结束时间
    params: depositPrice : number : 定金价格
    params: depositPriceContent : string : 定金权益内容
    params: posters : array : 爱车海报
              imageUrl : string : 图片地址
              modelId : string : 车型ID
    params: sharePosters : array : 分享海报
              imageUrl : string : 
              modelId : string : 
    params: carDetailPics : array : 车详情图片
              imageUrl : string : 
              modelId : string : 
    params: prePricePosters : array : 预订金海报
              imageUrl : string : 
              modelId : string : 
    params: promptDesc : string : 提示文案
    params: modelId : string : 车型ID
    params: status : number : 状态(0禁用1启用)
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/goods/carmodel/saveManageCarModel"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "carName": carName,  # 车系名称
        "brandName": brandName,  # 品牌名称
        "version": version,  # 品牌代码
        "carCode": carCode,  # 车系代码
        "modelName": modelName,  # 车型名称
        "modelCode": modelCode,  # 车型代号
        "carSimpleName": carSimpleName,  # 车型销售名称
        "configCode": configCode,  # 配置编码
        "sort": sort,  # 车型权重
        "price": price,  # 基础零售价
        "carDetailType": carDetailType,  # 车型详情类型 - 1:图片，2:H5连接
        "carDetailUrl": carDetailUrl,  # 车型详情类型为2 h5跳转地址
        "preStartTime": preStartTime,  # 预订开始时间
        "preEndTime": preEndTime,  # 预订结束时间
        "preToDepositStartTime": preToDepositStartTime,  # 预订转大定开始时间
        "preToDepositEndTime": preToDepositEndTime,  # 预订转大定结束时间
        "prePrice": prePrice,  # 预订金价格
        "prePriceContent": prePriceContent,  # 预订权益内容
        "depositStartTime": depositStartTime,  # 大定开始时间
        "depositEndTime": depositEndTime,  # 大定结束时间
        "depositPrice": depositPrice,  # 定金价格
        "depositPriceContent": depositPriceContent,  # 定金权益内容
        "posters": posters,  # 爱车海报
        "sharePosters": sharePosters,  # 分享海报
        "carDetailPics": carDetailPics,  # 车详情图片
        "prePricePosters": prePricePosters,  # 预订金海报
        "promptDesc": promptDesc,  # 提示文案
        "modelId": modelId,  # 车型ID
        "status": status,  # 状态(0禁用1启用)
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/carmodel/removeById")
def goods_carmodel_removebyid(modelId=None, headers=None, **kwargs):
    """
    删除车型-Y
    up_time=1675660050

    params: modelId :  : 车型id
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "GET"
    _url = "/goods/carmodel/removeById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "modelId": modelId,  # 车型id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/carmodel/getCarModelManageById")
def goods_carmodel_getcarmodelmanagebyid(modelId=None, headers=None, **kwargs):
    """
    查询车型详细信息-Y
    up_time=1675663920

    params: modelId :  : 车型编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              statusName : string : 状态(0.禁用 1.启用 2.删除)
              commodityWebUrl : string : 商品地址
              optional : string : 配置与选装
              appearances : array : 外观
              trims : array : 
              posters : array : 爱车海报
              sharePosters : array : 分享海报
              carDetailPics : array : 车型详情类型 - 1：车详情图片
              prePricePosters : array : 预订金海报
              carModelBatteries : array : 
              carModelItems : array : 
              dType : integer : 前端展示哪个订（定）  处于小订 为 0 处于大定 1 非此两个阶段是 2
    """
    _method = "GET"
    _url = "/goods/carmodel/getCarModelManageById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "modelId": modelId,  # 车型编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/carmodel/getManageCarModel")
def goods_carmodel_getmanagecarmodel(modelCode=None, size=None, carName=None, operator=None, version=None, carCode=None, brandName=None, modelName=None, status=None, current=None, headers=None, **kwargs):
    """
    车型列表-Y
    up_time=1675661996

    params: current :  : 分页
    params: size :  : 分页
    params: modelName :  : 车型名称
    params: modelCode :  : 车型代号
    params: status :  : 0:待启用，1:启用，2:禁用 车型新增默认状态待启用，全部则不传值
    params: operator :  : 操作人
    params: brandName :  : 品牌名称
    params: version :  : 品牌编码
    params: carName :  : 车系名称
    params: carCode :  : 车型编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : number : 
              maxLimit : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/goods/carmodel/getManageCarModel"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,  # 分页
        "size": size,  # 分页
        "modelName": modelName,  # 车型名称
        "modelCode": modelCode,  # 车型代号
        "status": status,  # 0:待启用，1:启用，2:禁用 车型新增默认状态待启用，全部则不传值
        "operator": operator,  # 操作人
        "brandName": brandName,  # 品牌名称
        "version": version,  # 品牌编码
        "carName": carName,  # 车系名称
        "carCode": carCode,  # 车型编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/carmodel/getModelNameList")
def goods_carmodel_getmodelnamelist( headers=None, **kwargs):
    """
    订单管理-查询可试驾车型-Y
    up_time=1675234063

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              modelId : string : 
              brandName : string : 
              version : string : 
              carName : string : 
              carCode : string : 
              modelName : string : 
              modelCode : string : 
              carSimpleName : string : 
              configCode : string : 
              sort : number : 
              price : number : 
              carDetailType : number : 
              carDetailUrl : string : 
              preStartTime : string : 
              preEndTime : string : 
              preToDepositStartTime : string : 
              preToDepositEndTime : string : 
              prePrice : number : 
              prePriceContent : string : 
              depositStartTime : string : 
              depositEndTime : string : 
              depositPrice : number : 
              depositPriceContent : string : 
              status : number : 
              createBy : string : 
              createTime : string : 
              updateBy : string : 
              updateTime : string : 
              financeDesc : null : 
              modelDesc : null : 
              announcementCode : null : 
              listingTime : null : 
              setOfCars : null : 
              modelImageUrl : null : 
              operator : null : 
              createByName : null : 
              updateByName : null : 
    """
    _method = "GET"
    _url = "/goods/carmodel/getModelNameList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/carmodel/getCarNameList")
def goods_carmodel_getcarnamelist( headers=None, **kwargs):
    """
    车型下拉列表-Y
    up_time=1675659976

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 车型名称集合
              type : string : None
              description : 车型名称 : None
    """
    _method = "GET"
    _url = "/goods/carmodel/getCarNameList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.manageapi.order.asserts_manageapi_order_mainorder import AssertsManageapiOrderMainorder
from service.app_a.apis.manageapi.order import apis_manageapi_order_mainorder


class FunsManageapiOrderMainorder(AssertsManageapiOrderMainorder):
    @allure.step(title="订单管理-后台查询订单列表-Y")
    def manageapi_order_mainorder_pagelist(self, createEndTime="$None$", orderStatus="$None$", extOrderStatus="$None$", mainOrderId="$None$", userName="$None$", extNum="$None$", size=10, channel="$None$", dealerCode="$None$", cityId="$None$", mobile="$None$", provinceId="$None$", orderId="$None$", createStartTime="$None$", orderType="$None$", modelId="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/manageapi/order/mainOrder/pageList
                params: mobile :  : 购买人手机号
                params: userName :  : 购买人
                params: modelId :  : 车型ID
                params: provinceId :  : 省编码
                params: cityId :  : 市编码
                params: orderId :  : 从新增大定逻辑开始，该字段定义为子订单号
                * * 小订转大定时，前端需要通过这个子订单号小订转大定
                params: mainOrderId :  : 主订单号
                params: orderStatus :  : 订单状态
                params: extOrderStatus :  : 第三方订单状态
                params: dealerCode :  : 经销商ID
                params: orderType :  : 订单类型
                params: channel :  : 渠道id 1 app 2 小程序 3 官网
                params: createStartTime :  : 订单创建开始日期
                params: createEndTime :  : 订单创建结束日期
                params: extNum :  : 三方订单号
                params: current :  :
                params: size :  :
                params: headers : 请求头
        """
        createEndTime = self.get_list_choice(createEndTime, list_or_dict=None, key="createEndTime")
        orderStatus = self.get_list_choice(orderStatus, list_or_dict=None, key="orderStatus")
        extOrderStatus = self.get_list_choice(extOrderStatus, list_or_dict=None, key="extOrderStatus")
        mainOrderId = self.get_list_choice(mainOrderId, list_or_dict=None, key="mainOrderId")
        userName = self.get_list_choice(userName, list_or_dict=None, key="userName")
        extNum = self.get_list_choice(extNum, list_or_dict=None, key="extNum")
        channel = self.get_list_choice(channel, list_or_dict=None, key="channel")
        dealerCode = self.get_list_choice(dealerCode, list_or_dict=None, key="dealerCode")
        cityId = self.get_list_choice(cityId, list_or_dict=None, key="cityId")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        provinceId = self.get_list_choice(provinceId, list_or_dict=None, key="provinceId")
        orderId = self.get_list_choice(orderId, list_or_dict=None, key="orderId")
        createStartTime = self.get_list_choice(createStartTime, list_or_dict=None, key="createStartTime")
        orderType = self.get_list_choice(orderType, list_or_dict=None, key="orderType")
        modelId = self.get_list_choice(modelId, list_or_dict=None, key="modelId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_manageapi_order_mainorder.manageapi_order_mainorder_pagelist(**_kwargs)

        self.assert_manageapi_order_mainorder_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-大订订单详情-Y")
    def manageapi_order_mainorder_detail(self, orderId="$None$", _assert=True,  **kwargs):
        """
            url=/manageapi/order/mainOrder/detail
                params: orderId :  :
                params: headers : 请求头
        """
        orderId = self.get_list_choice(orderId, list_or_dict=None, key="orderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_manageapi_order_mainorder.manageapi_order_mainorder_detail(**_kwargs)

        self.assert_manageapi_order_mainorder_detail(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/page")
def page(shopBusinessType=None, city=None, size=None, cityNameSort=None, provinceNameSort=None, province=None, districtNameSort=None, dealerCode=None, dealerAddress=None, dealerName=None, district=None, current=None, headers=None, **kwargs):
    """
    网点列表-获取经销商
    up_time=1675233719

    params: current :  : 
    params: size :  : 
    params: province :  : 
    params: city :  : 
    params: district :  : 
    params: dealerCode :  : 
    params: dealerName :  : 
    params: dealerAddress :  : 
    params: shopBusinessType :  : 
    params: cityNameSort :  : 
    params: districtNameSort :  : 
    params: provinceNameSort :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "province": province,
        "city": city,
        "district": district,
        "dealerCode": dealerCode,
        "dealerName": dealerName,
        "dealerAddress": dealerAddress,
        "shopBusinessType": shopBusinessType,
        "cityNameSort": cityNameSort,
        "districtNameSort": districtNameSort,
        "provinceNameSort": provinceNameSort,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/question/answerQuestion")
def content_question_answerquestion(questionId=None, answerContent=None, author=None, headers=None, **kwargs):
    """
    问答-回复问题-Y
    up_time=1675680341

    params: questionId : string : 问题主键
    params: answerContent : string : 回答内容
    params: author : number : 作者
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/question/answerQuestion"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "questionId": questionId,  # 问题主键
        "answerContent": answerContent,  # 回答内容
        "author": author,  # 作者
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/question/revoke")
def content_question_revoke(operaType=None, questionId=None, headers=None, **kwargs):
    """
    问答-回答撤回归档-Y
    up_time=1675740174

    params: operaType : string : 操作类型3：撤回4：归档
    params: questionId : string : 回复主键
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/content/question/revoke"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "operaType": operaType,  # 操作类型3：撤回4：归档
        "questionId": questionId,  # 回复主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/question/getManegeQuestionList")
def content_question_getmanegequestionlist(size=None, keyWord=None, endTime=None, startTime=None, mobile=None, status=None, current=None, headers=None, **kwargs):
    """
    问答-搜索问题列表-Y
    up_time=1675740163

    params: keyWord :  : 关键字
    params: mobile :  : 发布人手机号
    params: startTime :  : 搜索起始时间
    params: endTime :  : 搜索结束时间
    params: status :  : 问答状态1：已回复、0：待回复、3：已撤回、4：已归档
    params: size :  : 每页数据量
    params: current :  : 页数
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 数量
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/question/getManegeQuestionList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "keyWord": keyWord,  # 关键字
        "mobile": mobile,  # 发布人手机号
        "startTime": startTime,  # 搜索起始时间
        "endTime": endTime,  # 搜索结束时间
        "status": status,  # 问答状态1：已回复、0：待回复、3：已撤回、4：已归档
        "size": size,  # 每页数据量
        "current": current,  # 页数
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/question/getById")
def content_question_getbyid(questionId=None, headers=None, **kwargs):
    """
    问答-获取问题详情页面-Y
    up_time=1675740037

    params: questionId :  : 问题主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              questionId : string : 问题id
              content : string : 内容
              classifyId : string : 分类id
              chackStatus : number : 状态  0：待回复 1.已回复 3.已撤回 4.已归档
              ansCnt : string : 回答数量
              reason : null : 原因
              checkTime : null : 审核时间
              checkBy : string : 审核人
              delFlag : number : 是否删除  1.已删除
              createTime : string : 创建时间
              createBy : string : 创建人id
              updateTime : null : 修改时间
              updateBy : null : 修改人id
              picUrls : array : 图片集合
              userType : number : 用户类型
              classifyName : string : 分类名称（页面显示）
              createAvatarUrl : string : 用户头像
              createName : string : 用户昵称
              answers : array : 回答
              keyWord : null : 
              mobile : string : 用户手机号
              startTime : null : 
              endTime : null : 
              status : null : 
    """
    _method = "GET"
    _url = "/content/question/getById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "questionId": questionId,  # 问题主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.content.asserts_content_contentmanager import AssertsContentContentmanager
from service.app_a.apis.content import apis_content_contentmanager


class FunsContentContentmanager(AssertsContentContentmanager):
    @allure.step(title="动态-评论列表-Y")
    def content_contentmanager_commentlist(self, size=10, contentId="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/contentManager/commentList
                params: contentId :  : 动态主键
                params: size :  : 每页数据数
                params: current :  : 当前页
                params: headers : 请求头
        """
        contentId = self.get_list_choice(contentId, list_or_dict=None, key="contentId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_contentmanager.content_contentmanager_commentlist(**_kwargs)

        self.assert_content_contentmanager_commentlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.admin.asserts_admin_spa import AssertsAdminSpa
from service.app_a.apis.admin import apis_admin_spa


class FunsAdminSpa(AssertsAdminSpa):
    @allure.step(title="获取guc appId")
    def admin_spa_getappid(self, _assert=True,  **kwargs):
        """
            url=/admin/spa/getAppId
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_admin_spa.admin_spa_getappid(**_kwargs)

        self.assert_admin_spa_getappid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.order.asserts_order_mainorder import AssertsOrderMainorder
from service.app_a.apis.order import apis_order_mainorder
from service.app_a.funs.order.mainorder.funs_order_mainorder_scrm2app import FunsOrderMainorderScrm2App


class FunsOrderMainorder(AssertsOrderMainorder, FunsOrderMainorderScrm2App):
    @allure.step(title="小订订单分页查询（后台）-Y")
    def order_mainorder_pagelist(self, createEndTime="$None$", size=10, sortItems="$None$", createStartTime="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/order/mainOrder/pageList
                params: current : string :
                params: size : string :
                params: sortItems : string : 排序字段（只能是【orderMain.orderType】、【orderMain.createTime】、【orderPay.createTime】）
                params: createStartTime : string : 订单创建开始日期
                params: createEndTime : string : 订单创建结束日期
                params: headers : 请求头
        """
        createEndTime = self.get_list_choice(createEndTime, list_or_dict=None, key="createEndTime")
        sortItems = self.get_list_choice(sortItems, list_or_dict=None, key="sortItems")
        createStartTime = self.get_list_choice(createStartTime, list_or_dict=None, key="createStartTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_pagelist(**_kwargs)

        self.assert_order_mainorder_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="小订订单列表导出（后台）-Y")
    def order_mainorder_download(self, createEndTime="$None$", orderTypeToSort="$None$", createTimeToSort="$None$", payTimeToSort="$None$", createStartTime="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/mainOrder/downLoad
                params: orderTypeToSort : string : 订单类型排序 不排序不赋值 正序：asc 倒序：desc
                params: createTimeToSort : string : 订单创建时间 不排序不赋值 正序：asc 倒序：desc
                params: payTimeToSort : string : 订单创建时间 不排序不赋值 正序：asc 倒序：desc
                params: createStartTime : string : 订单创建开始日期
                params: createEndTime : string : 订单创建结束日期
                params: headers : 请求头
        """
        createEndTime = self.get_value_choice(createEndTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderTypeToSort = self.get_value_choice(orderTypeToSort, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createTimeToSort = self.get_value_choice(createTimeToSort, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        payTimeToSort = self.get_value_choice(payTimeToSort, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createStartTime = self.get_value_choice(createStartTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_download(**_kwargs)

        self.assert_order_mainorder_download(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="小订订单查询订单详情（后台）-Y")
    def order_mainorder_detail(self, orderId="$None$", _assert=True,  **kwargs):
        """
            url=/order/mainOrder/detail
                params: orderId :  : 订单号
                params: headers : 请求头
        """
        orderId = self.get_list_choice(orderId, list_or_dict=None, key="orderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_detail(**_kwargs)

        self.assert_order_mainorder_detail(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-查询所有用户订单状态-Y")
    def order_mainorder_getuserorderstatuslist(self, _assert=True,  **kwargs):
        """
            url=/order/mainOrder/getUserOrderStatusList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_getuserorderstatuslist(**_kwargs)

        self.assert_order_mainorder_getuserorderstatuslist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-后台查询所有订单类型-Y")
    def order_mainorder_getordertypelist(self, _assert=True,  **kwargs):
        """
            url=/order/mainOrder/getOrderTypeList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_getordertypelist(**_kwargs)

        self.assert_order_mainorder_getordertypelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-后台查询所有销售单订单状态-Y")
    def order_mainorder_getextorderstatuslist(self, _assert=True,  **kwargs):
        """
            url=/order/mainOrder/getExtOrderStatusList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_getextorderstatuslist(**_kwargs)

        self.assert_order_mainorder_getextorderstatuslist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-查询所有订单状态-Y")
    def order_mainorder_getorderstatuslist(self, _assert=True,  **kwargs):
        """
            url=/order/mainOrder/getOrderStatusList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_getorderstatuslist(**_kwargs)

        self.assert_order_mainorder_getorderstatuslist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-通过vin码查询订单-Y")
    def order_mainorder_vincode(self, vin="$None$", _assert=True,  **kwargs):
        """
            url=/order/mainOrder/vinCode
                params: vin :  : 车辆唯一vin码
                params: headers : 请求头
        """
        vin = self.get_list_choice(vin, list_or_dict=None, key="vin")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_vincode(**_kwargs)

        self.assert_order_mainorder_vincode(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-订单完成-Y")
    def order_mainorder_finish(self, orderId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/mainOrder/finish
                params: orderId : string :
                params: headers : 请求头
        """
        orderId = self.get_value_choice(orderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_finish(**_kwargs)

        self.assert_order_mainorder_finish(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-查询订单权益接口-Y")
    def order_mainorder_allpricecontent(self, orderId="$None$", _assert=True,  **kwargs):
        """
            url=/order/mainOrder/allPriceContent
                params: orderId :  : 子订单号
                params: headers : 请求头
        """
        orderId = self.get_list_choice(orderId, list_or_dict=None, key="orderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_allpricecontent(**_kwargs)

        self.assert_order_mainorder_allpricecontent(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-通过用户ID查询订单ID-Y")
    def order_mainorder_getorderidbyuser(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/order/mainOrder/getOrderIdByUser
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_getorderidbyuser(**_kwargs)

        self.assert_order_mainorder_getorderidbyuser(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-通过订单号获取车型名称-Y")
    def order_mainorder__getmodelnamebyorderid(self, orderId="$None$", _assert=True,  **kwargs):
        """
            url=/order/mainOrder/=getModelNameByOrderId
                params: orderId :  :
                params: headers : 请求头
        """
        orderId = self.get_list_choice(orderId, list_or_dict=None, key="orderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder__getmodelnamebyorderid(**_kwargs)

        self.assert_order_mainorder__getmodelnamebyorderid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-通过订单号获取配置信息-Y")
    def order_mainorder_getcarconfigbyorderid(self, orderId="$None$", _assert=True,  **kwargs):
        """
            url=/order/mainOrder/getCarConfigByOrderId
                params: orderId :  :
                params: headers : 请求头
        """
        orderId = self.get_list_choice(orderId, list_or_dict=None, key="orderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_getcarconfigbyorderid(**_kwargs)

        self.assert_order_mainorder_getcarconfigbyorderid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="SCRM第三方订单同步信息-Y")
    def order_mainorder_syncscrmextorder(self, VIN="$None$", deliveryData="$None$", phone="$None$", ossId="$None$", potentialName="$None$", optionCode="$None$", orderId="$None$", updateTime="$None$", orderAllAmount="$None$", syncMsg="$None$", modelCode="$None$", isArrived="$None$", orderNo="$None$", unitInvoiceTitle="$None$", isTestDrive="$None$", scUname="$None$", syncStatus="$None$", customerCtCode="$None$", dealerCode="$None$", seriesCode="$None$", colorCode="$None$", trimCode="$None$", custCertNo="$None$", isLifetimeWarranty="$None$", createTime="$None$", lifetimeWarrantyPrice="$None$", customerId="$None$", customerType="$None$", soNo="$None$", unitTaxNo="$None$", soStatus="$None$", chargePointEquity="$None$", unitName="$None$", configCode="$None$", scUid="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/mainOrder/syncScrmExtOrder
                params: ossId : string : 主键
                params: dealerCode : string : 经销商代码
                params: customerId : number : 潜客 ID
                params: isArrived : string : 是否到店（true or false）
                params: isTestDrive : string : 是否试乘试驾（true or false）
                params: orderNo : string : 预订单单号
                params: orderId : number : 预订单订单 ID
                params: soNo : string : DMS 订单编号
                params: soStatus : string : 订单状态
                params: scUid : string : 销售顾问 ID
                params: scUname : string : 销售顾问姓名
                params: VIN : string : 车架号
                params: deliveryData : string : 承诺交车日期
                params: seriesCode : string : 车系代码
                params: modelCode : string : 车型代码
                params: configCode : string : 配置代码
                params: colorCode : string : 外观代码
                params: trimCode : string : 内饰代码
                params: optionCode : string : 选装包
                params: orderAllAmount : number : 订单价格(保留 3 位小数)
                params: customerType : string : 同步个人和企业
                params: potentialName : string : DMS 订单客户手机号
                params: phone : integer : DMS 订单客户证件类型
                params: customerCtCode : string : 证件号码
                params: custCertNo : string : 企业发票抬头
                params: unitName : string : 企业名称
                params: unitInvoiceTitle : string : 企业发票抬头
                params: unitTaxNo : integer : 企业税号
                params: chargePointEquity : integer : 充电桩权益      * 30471001: 7KW 充电桩      * 30471002: 11KW 充电桩      * 30471003: 家充桩置换公充权益      * 30471004:无电车权益
                params: isLifetimeWarranty : integer : (10041001 是, 10041002 否)
                params: lifetimeWarrantyPrice : string : 终身质保价格(保留 2 位小数)
                params: createTime : string : 创建订单时间
                params: updateTime : string : 更新订单时间
                params: syncStatus : integer : 0待同步，1同步成功，2同步失败
                params: syncMsg : string : 同步结果
                params: headers : 请求头
        """
        VIN = self.get_value_choice(VIN, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        deliveryData = self.get_value_choice(deliveryData, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        phone = self.get_value_choice(phone, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        ossId = self.get_value_choice(ossId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        potentialName = self.get_value_choice(potentialName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        optionCode = self.get_value_choice(optionCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderId = self.get_value_choice(orderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        updateTime = self.get_value_choice(updateTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderAllAmount = self.get_value_choice(orderAllAmount, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        syncMsg = self.get_value_choice(syncMsg, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelCode = self.get_value_choice(modelCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isArrived = self.get_value_choice(isArrived, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderNo = self.get_value_choice(orderNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        unitInvoiceTitle = self.get_value_choice(unitInvoiceTitle, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isTestDrive = self.get_value_choice(isTestDrive, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        scUname = self.get_value_choice(scUname, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        syncStatus = self.get_value_choice(syncStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        customerCtCode = self.get_value_choice(customerCtCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        dealerCode = self.get_value_choice(dealerCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        seriesCode = self.get_value_choice(seriesCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        colorCode = self.get_value_choice(colorCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        trimCode = self.get_value_choice(trimCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        custCertNo = self.get_value_choice(custCertNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        isLifetimeWarranty = self.get_value_choice(isLifetimeWarranty, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createTime = self.get_value_choice(createTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        lifetimeWarrantyPrice = self.get_value_choice(lifetimeWarrantyPrice, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        customerId = self.get_value_choice(customerId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        customerType = self.get_value_choice(customerType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        soNo = self.get_value_choice(soNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        unitTaxNo = self.get_value_choice(unitTaxNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        soStatus = self.get_value_choice(soStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        chargePointEquity = self.get_value_choice(chargePointEquity, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        unitName = self.get_value_choice(unitName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        configCode = self.get_value_choice(configCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        scUid = self.get_value_choice(scUid, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_syncscrmextorder(**_kwargs)

        self.assert_order_mainorder_syncscrmextorder(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="SCRM第三方转派经销商通知APP同步日志-Y")
    def order_mainorder_informorder(self, systemCode="$None$", sourceInfo="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/mainOrder/informOrder
                params: sourceInfo : array : 批量操作
                orderId : string : 订单ID
                customerId : number : 潜客ID
                dealerCode : string : 经销商代码(变更后的经销商)
                orderNo : number : 预订单单号
                soNo : string : DMS订单编号
                soStatus : string : 订单状态
                scUid : string : 销售顾问ID
                scUname : string : 销售顾问姓名
                params: systemCode : string : 变更系统
                params: headers : 请求头
        """
        systemCode = self.get_value_choice(systemCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sourceInfo = self.get_value_choice(sourceInfo, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder.order_mainorder_informorder(**_kwargs)

        self.assert_order_mainorder_informorder(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/common/systemversion/save")
def common_systemversion_save(remark=None, size=None, name=None, force=None, version=None, downloadUrl=None, versionId=None, content=None, publishStatus=None, classify=None, headers=None, **kwargs):
    """
    保存版本信息-Y
    up_time=1675326010

    params: version : string : 版本号
    params: name : string : 版本名称
    params: content : string : 更新内容
    params: remark : string : 备注
    params: classify : string :  Android或IOS
    params: force : string : 强制更新0.否1.是
    params: downloadUrl : string : 下载路径
    params: size : string : 大小
    params: versionId : number : 主键，更新传，新增不传
    params: publishStatus : number : 0. 未发布 1.已发布
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/common/systemversion/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "version": version,  # 版本号
        "name": name,  # 版本名称
        "content": content,  # 更新内容
        "remark": remark,  # 备注
        "classify": classify,  #  Android或IOS
        "force": force,  # 强制更新0.否1.是
        "downloadUrl": downloadUrl,  # 下载路径
        "size": size,  # 大小
        "versionId": versionId,  # 主键，更新传，新增不传
        "publishStatus": publishStatus,  # 0. 未发布 1.已发布
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/systemversion/page")
def common_systemversion_page( headers=None, **kwargs):
    """
    查询版本信息-Y
    up_time=1675325747

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : number : 
              maxLimit : number : 
              pages : number : 
    """
    _method = "GET"
    _url = "/common/systemversion/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.radarpoints.asserts_radarpoints_adjustpoints import AssertsRadarpointsAdjustpoints
from service.app_a.apis.radarpoints import apis_radarpoints_adjustpoints
from service.app_a.funs.radarpoints.adjustpoints.funs_radarpoints_adjustpoints_adjust import FunsRadarpointsAdjustpointsAdjust


class FunsRadarpointsAdjustpoints(AssertsRadarpointsAdjustpoints, FunsRadarpointsAdjustpointsAdjust):
    @allure.step(title="积分调整 - 分页查询")
    def radarpoints_adjustpoints_pagelist(self, userId="$None$", current=1, adjustTimeBefore="$None$", size=10, adjustNotes="$None$", mobile="$None$", adjustTimeEnd="$None$", nickName="$None$", optAbility="$None$", optAbilityName="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/adjustPoints/pageList
                params: nickName :  : 用户名
                params: mobile :  : 手机号
                params: adjustNotes :  : 调整原因说明
                params: optAbility :  : 调整积分方式
                params: optAbilityName :  : 调整积分方式枚举
                params: adjustTimeBefore :  : 调整时间 - 开始
                params: adjustTimeEnd :  : 调整时间 - 结束
                params: current :  : 页码
                params: size :  : 每页大小
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        adjustTimeBefore = self.get_list_choice(adjustTimeBefore, list_or_dict=None, key="adjustTimeBefore")
        adjustNotes = self.get_list_choice(adjustNotes, list_or_dict=None, key="adjustNotes")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        adjustTimeEnd = self.get_list_choice(adjustTimeEnd, list_or_dict=None, key="adjustTimeEnd")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        optAbility = self.get_list_choice(optAbility, list_or_dict=None, key="optAbility")
        optAbilityName = self.get_list_choice(optAbilityName, list_or_dict=None, key="optAbilityName")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_adjustpoints.radarpoints_adjustpoints_pagelist(**_kwargs)

        self.assert_radarpoints_adjustpoints_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分调整 - 根据UserId查询详情")
    def radarpoints_adjustpoints_getuserpointsqtybyuserid(self, userId="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/adjustPoints/getUserPointsQtyByUserId
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_adjustpoints.radarpoints_adjustpoints_getuserpointsqtybyuserid(**_kwargs)

        self.assert_radarpoints_adjustpoints_getuserpointsqtybyuserid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分调整 - 根据Mobile查询详情")
    def radarpoints_adjustpoints_getuserpointsqtybymobile(self, mobile="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/adjustPoints/getUserPointsQtyByMobile
                params: mobile :  : 手机号码
                params: headers : 请求头
        """
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_adjustpoints.radarpoints_adjustpoints_getuserpointsqtybymobile(**_kwargs)

        self.assert_radarpoints_adjustpoints_getuserpointsqtybymobile(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分调整 - 导出excel")
    def radarpoints_adjustpoints_export(self, userId="$None$", current=1, adjustTimeBefore="$None$", size=10, adjustNotes="$None$", mobile="$None$", adjustTimeEnd="$None$", nickName="$None$", optAbility="$None$", optAbilityName="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/adjustPoints/export
                params: nickName :  : 用户名
                params: mobile :  : 手机号
                params: adjustNotes :  : 调整原因说明
                params: optAbility :  : 调整积分方式
                params: optAbilityName :  : 调整积分方式枚举
                params: adjustTimeBefore :  : 调整时间 - 开始
                params: adjustTimeEnd :  : 调整时间 - 结束
                params: current :  : 页码
                params: size :  : 每页大小
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        adjustTimeBefore = self.get_list_choice(adjustTimeBefore, list_or_dict=None, key="adjustTimeBefore")
        adjustNotes = self.get_list_choice(adjustNotes, list_or_dict=None, key="adjustNotes")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        adjustTimeEnd = self.get_list_choice(adjustTimeEnd, list_or_dict=None, key="adjustTimeEnd")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        optAbility = self.get_list_choice(optAbility, list_or_dict=None, key="optAbility")
        optAbilityName = self.get_list_choice(optAbilityName, list_or_dict=None, key="optAbilityName")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_adjustpoints.radarpoints_adjustpoints_export(**_kwargs)

        self.assert_radarpoints_adjustpoints_export(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





from service.app_a.funs.radarpoints.adjustpoints.adjust.funs_radarpoints_adjustpoints_adjust_single import FunsRadarpointsAdjustpointsAdjustSingle
from service.app_a.funs.radarpoints.adjustpoints.adjust.funs_radarpoints_adjustpoints_adjust_batch import FunsRadarpointsAdjustpointsAdjustBatch


class FunsRadarpointsAdjustpointsAdjust(FunsRadarpointsAdjustpointsAdjustSingle, FunsRadarpointsAdjustpointsAdjustBatch):
    pass




import allure

from service.app_a import unit_request
from service.app_a.sqls.goods.sqls_goods_ordermain import SqlsGoodsOrdermain


class AssertsGoodsOrdermain(SqlsGoodsOrdermain):
    @allure.step(title="接口返回结果校验")
    def assert_goods_ordermain_pay(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_ordermain_pay(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderMainId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_ordermain_orderexports(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_ordermain_orderexports(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["billStatus", "exportType", "shopName", "userName", "endTime", "testDriveIdStr", "modelName", "userMobile", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_ordermain_getordermainpage(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_ordermain_getordermainpage(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["shopName", "userName", "orderStatus", "endTime", "modelName", "userMobile", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_ordermain_getordermainbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_ordermain_getordermainbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderMainId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.content.asserts_content_topic4c import AssertsContentTopic4C
from service.app_a.apis.content import apis_content_topic4c


class FunsContentTopic4C(AssertsContentTopic4C):
    @allure.step(title="话题-删除话题")
    def content_topic4c_del(self, topicId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/topic4C/del
                params: topicId : string : 话题主键
                params: headers : 请求头
        """
        topicId = self.get_value_choice(topicId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_topic4c.content_topic4c_del(**_kwargs)

        self.assert_content_topic4c_del(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="话题-获取动态关联列表-Y")
    def content_topic4c_getcontentlist(self, topicId="$None$", size=10, current=1, _assert=True,  **kwargs):
        """
            url=/content/topic4C/getContentList
                params: topicId :  : 话题主键
                params: size :  : 每页数据数
                params: current :  : 当前页
                params: headers : 请求头
        """
        topicId = self.get_list_choice(topicId, list_or_dict=None, key="topicId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_topic4c.content_topic4c_getcontentlist(**_kwargs)

        self.assert_content_topic4c_getcontentlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="话题-搜索话题列表")
    def content_topic4c_list(self, size=10, keyWord="$None$", topicId="$None$", endTime="$None$", createBy="$None$", startTime="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/topic4C/list
                params: topicId :  : 话题主键
                params: createBy :  : 发布人主键
                params: keyWord :  : 话题关键字
                params: startTime :  : 搜索开始时间
                params: endTime :  : 搜索结束时间
                params: size :  : 每页数量数
                params: current :  : 当前页
                params: headers : 请求头
        """
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        topicId = self.get_list_choice(topicId, list_or_dict=None, key="topicId")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        createBy = self.get_list_choice(createBy, list_or_dict=None, key="createBy")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_topic4c.content_topic4c_list(**_kwargs)

        self.assert_content_topic4c_list(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="话题-新增话题")
    def content_topic4c_insert(self, topicTitle="$None$", topicId="$None$", author="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/topic4C/insert
                params: topicId : string : 话题主键
                params: topicTitle : string : 话题
                params: author : number : 话题作者
                params: headers : 请求头
        """
        topicTitle = self.get_value_choice(topicTitle, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        topicId = self.get_value_choice(topicId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        author = self.get_value_choice(author, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_topic4c.content_topic4c_insert(**_kwargs)

        self.assert_content_topic4c_insert(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="话题-置顶")
    def content_topic4c_top(self, topicId="$None$", type="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/topic4C/top
                params: topicId : string : 话题主键
                params: type : string : 操作类型1：置顶2：取消置顶
                params: headers : 请求头
        """
        topicId = self.get_value_choice(topicId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        type = self.get_value_choice(type, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_topic4c.content_topic4c_top(**_kwargs)

        self.assert_content_topic4c_top(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_commonquestion import SqlsContentCommonquestion


class AssertsContentCommonquestion(SqlsContentCommonquestion):
    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_updatestatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_updatestatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["status", "essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["title", "content", "essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_updaterank(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_updaterank(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rank", "essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_delete(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_delete(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_publishlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_publishlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["title", "content", "essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_createid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_createid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_commonquestion_info(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_commonquestion_info(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_adv import SqlsContentAdv


class AssertsContentAdv(SqlsContentAdv):
    @allure.step(title="接口返回结果校验")
    def assert_content_adv_save(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_save(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["jumpContent", "advPicUrl", "advText", "jumpType", "advId", "advLinkUrl", "bindingFlag", "version", "advSerial", "advPlaceId", "pictureList"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_updateessayadvlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_updateessayadvlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_settopflag(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_settopflag(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_advplacelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_advplacelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["advPlaceId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_delete(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_delete(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["advId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_detailadmin(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_detailadmin(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["advPlaceId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_saveall(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_saveall(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["jumpType", "advPlaceId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_jumpcontent(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_jumpcontent(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["typeCode", "keyWord"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_detailcontentadmin(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_detailcontentadmin(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderByCommentCnt", "essayKeyWords"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_jumptypelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_jumptypelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_cancelrecommend(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_cancelrecommend(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_adv_detail(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_adv_detail(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["advPlaceId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.order.sqls_order_testdrive import SqlsOrderTestdrive


class AssertsOrderTestdrive(SqlsOrderTestdrive):
    @allure.step(title="接口返回结果校验")
    def assert_order_testdrive_exportlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_testdrive_exportlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["createByName", "createTime", "shopName", "phoneNumber", "channel", "endTime", "id", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_testdrive_userlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_testdrive_userlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["modelId", "createBy"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.asserts_activitymanager import AssertsActivitymanager
from service.app_a.apis import apis_activitymanager


class FunsActivitymanager(AssertsActivitymanager):
    @allure.step(title="后台管理-置顶接口-Y")
    def activitymanager_updateactivitytop(self, topFlag="$None$", activityId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/activityManager/updateActivityTop
                params: activityId : string : 活动主键
                params: topFlag : integer : 活动置顶标识 0-不置顶 1-置顶
                params: headers : 请求头
        """
        topFlag = self.get_value_choice(topFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        activityId = self.get_value_choice(activityId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_activitymanager.activitymanager_updateactivitytop(**_kwargs)

        self.assert_activitymanager_updateactivitytop(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_agreement import SqlsContentAgreement


class AssertsContentAgreement(SqlsContentAgreement):
    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_getagreement(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_getagreement(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_getbycode(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_getbycode(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["agreementCode"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_getagreementbycode(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_getagreementbycode(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["agreementCode"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_updatestatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_updatestatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["code", "agreementId", "status"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_save(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_save(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["code", "content", "name", "version"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["code", "name", "agreementId", "version", "content"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_agreement_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_agreement_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["agreementId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_campmanager import SqlsContentCampmanager


class AssertsContentCampmanager(SqlsContentCampmanager):
    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["sortBody", "name", "id", "sortord", "createBy", "status"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_soldout(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_soldout(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id", "campId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_insertcampid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_insertcampid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["city", "campDetail", "name", "url", "province", "discountExpEndTime", "discountExpBeginTime", "id", "campTradeTime", "county", "ownerDiscount", "content", "address"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_detail_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_detail_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["phone", "discountExpEndTime", "discountExpBeginTime", "ownerDiscount", "areaCode"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/contentManager/commentList")
def content_contentmanager_commentlist(size=None, contentId=None, current=None, headers=None, **kwargs):
    """
    动态-评论列表-Y
    up_time=1675650512

    params: contentId :  : 动态主键
    params: size :  : 每页数据数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : array : 
              commentId : string : 评论主键
              topFlag : number : 是否置顶1：是0：否
              checkTime : string : 发布时间
              contentDesc : string : 评论内容
              createName : string : 创建人
              createImg : string : 创建人头像
              mobile : string : 手机号
    """
    _method = "GET"
    _url = "/content/contentManager/commentList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "contentId": contentId,  # 动态主键
        "size": size,  # 每页数据数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/noticeManager/page")
def content_noticemanager_page( headers=None, **kwargs):
    """
    系统通知列表查询接口-Y
    up_time=1675652796

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/noticeManager/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/noticeManager/getNoticeParamsList/")
def content_noticemanager_getnoticeparamslist_(messageId=None, templateType=None, headers=None, **kwargs):
    """
    获取系统通知详情
    up_time=1675133819

    params: messageId :  : 
    params: templateType :  : 模板编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/noticeManager/getNoticeParamsList/{messageId}"
    _url = get_url(_url, locals())

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "templateType": templateType,  # 模板编码
    }

    _params = {
        "messageId": messageId,
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/noticeManager/noticeParamsUpdate")
def content_noticemanager_noticeparamsupdate(templateName=None, templateContent=None, templateType=None, headers=None, **kwargs):
    """
    系统通知变量编辑-Y
    up_time=1675652880

    params: templateType : string : 模板类型
    params: templateName : string : 模板名称（标题）
    params: templateContent : string : 模板内容
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/noticeManager/noticeParamsUpdate"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "templateType": templateType,  # 模板类型
        "templateName": templateName,  # 模板名称（标题）
        "templateContent": templateContent,  # 模板内容
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.order.rightsorder.sqls_order_rightsorder_receive import SqlsOrderRightsorderReceive


class AssertsOrderRightsorderReceive(SqlsOrderRightsorderReceive):
    @allure.step(title="接口返回结果校验")
    def assert_order_rightsorder_receive_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_rightsorder_receive_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["rightsId", "rightsName", "rightsType", "userId", "refundDate", "createTime", "receiveDate", "refundBillNo", "updateId", "payBillNo", "payDate", "mobile", "payAmount", "createBy", "rightsOrderId", "updateTime", "orderMainId", "useStatus"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.content.asserts_content_advplace import AssertsContentAdvplace
from service.app_a.apis.content import apis_content_advplace


class FunsContentAdvplace(AssertsContentAdvplace):
    @allure.step(title="点位-更新大点位内容")
    def content_advplace_updatename(self, startFlag="$None$", playTime="$None$", advPlaceId="$None$", advPlaceName="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/advplace/updateName
                params: advPlaceId : text :
                params: advPlaceName : text :
                params: startFlag : text : 广告页广告位必传
                params: playTime : text : 广告页广告位必传
                params: headers : 请求头
        """
        startFlag = self.get_value_choice(startFlag, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        playTime = self.get_value_choice(playTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advPlaceId = self.get_value_choice(advPlaceId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        advPlaceName = self.get_value_choice(advPlaceName, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_advplace.content_advplace_updatename(**_kwargs)

        self.assert_content_advplace_updatename(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.asserts_content_recruit import AssertsContentRecruit
from service.app_a.apis.content import apis_content_recruit


class FunsContentRecruit(AssertsContentRecruit):
    @allure.step(title="招聘信息保存-Y")
    def content_recruit_save(self, fileUrl="$None$", fileName="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/recruit/save
                params: fileName : string : 文件名
                params: fileUrl : string : 文件url
                params: headers : 请求头
        """
        fileUrl = self.get_value_choice(fileUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        fileName = self.get_value_choice(fileName, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_recruit.content_recruit_save(**_kwargs)

        self.assert_content_recruit_save(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="招聘信息查询-Y")
    def content_recruit_detail(self, _assert=True,  **kwargs):
        """
            url=/content/recruit/detail
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_recruit.content_recruit_detail(**_kwargs)

        self.assert_content_recruit_detail(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/order/rights/rightsManager/createId")
def order_rights_rightsmanager_createid( headers=None, **kwargs):
    """
    自动生成权益ID-Y
    up_time=1675407827

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : string : 
    """
    _method = "GET"
    _url = "/order/rights/rightsManager/createId"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rights/rightsManager/getRelation")
def order_rights_rightsmanager_getrelation(rightsId=None, headers=None, **kwargs):
    """
    查询互斥关系接口-Y
    up_time=1675409057

    params: rightsId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0失败1成功
    params: msg : string : 
    params: data : array : 
              rightsId : number : 主键
              rightsName : string : 互斥关系
    """
    _method = "GET"
    _url = "/order/rights/rightsManager/getRelation"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "rightsId": rightsId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rights/rightsManager/page")
def order_rights_rightsmanager_page(rightsName=None, modelCode=None, size=None, effectiveEndDate=None, status=None, current=None, headers=None, **kwargs):
    """
    权益 - 分页查询-Y
    up_time=1675409025

    params: size :  : 
    params: current :  : 
    params: rightsName :  : 
    params: status :  : 
    params: modelCode :  : 
    params: effectiveEndDate :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0失败1成
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : string : 
              current : string : 
    """
    _method = "GET"
    _url = "/order/rights/rightsManager/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "size": size,
        "current": current,
        "rightsName": rightsName,
        "status": status,
        "modelCode": modelCode,
        "effectiveEndDate": effectiveEndDate,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rights/rightsManager/getRightsList")
def order_rights_rightsmanager_getrightslist(rightsName=None, effectiveStartDate=None, modelId=None, status=None, headers=None, **kwargs):
    """
    权益订单 - 查询-Y
    up_time=1675669230

    params: rightsName : string : 权益名称
    params: status : integer : 权益状态(0未生效，1已生效)
    params: modelId : string : 车型代码
    params: effectiveStartDate : string : 权益生效时间
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              rightsId : number : 主键
              rightsType : string : 权益类型
              rightsName : string : 权益名称
              content : string : 权益描述
              buyAmount : string : 权益购买金额
              discountAmount : string : 权益优惠金额
              modelId : string : 车型id
              modelCode : string : 车型代码
              orderType : string : 关联订单类型
              relation : string : 互斥关系
              status : integer : 权益状态(0未生效，1已生效)
              effectiveDate : string : 权益生效时间
              effectiveStartDate : string : 权益生效时间 -- 开始
              effectiveEndDate : string : 权益生效时间 -- 结束
              createTime : string : 创建时间
              createBy : number : 创建人
              updateTime : string : 更新时间
              updateId : number : 更新人id
              delFlag : integer : 删除标识 0：否 1：是
              CarModelInfo : object : 
    """
    _method = "POST"
    _url = "/order/rights/rightsManager/getRightsList"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "rightsName": rightsName,  # 权益名称
        "status": status,  # 权益状态(0未生效，1已生效)
        "modelId": modelId,  # 车型代码
        "effectiveStartDate": effectiveStartDate,  # 权益生效时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rights/rightsManager/insert")
def order_rights_rightsmanager_insert(rightsId=None, modelCode=None, rightsName=None, rightsType=None, orderType=None, effectiveStartDate=None, headers=None, **kwargs):
    """
    权益-新增权益-Y
    up_time=1675669334

    params: effectiveStartDate : text : 权益生效时间 -- 开始
    params: rightsId : text : 权益ID
    params: rightsName : text : 权益名称
    params: rightsType : text : 权益类型
    params: modelCode : text : 车型代码
    params: orderType : text : 关联订单类型code
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0失败 1成功
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/order/rights/rightsManager/insert"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "effectiveStartDate": effectiveStartDate,  # 权益生效时间 -- 开始
        "rightsId": rightsId,  # 权益ID
        "rightsName": rightsName,  # 权益名称
        "rightsType": rightsType,  # 权益类型
        "modelCode": modelCode,  # 车型代码
        "orderType": orderType,  # 关联订单类型code
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rights/rightsManager/update")
def order_rights_rightsmanager_update(rightsName=None, rightsId=None, Content=None, effectiveStartDate=None, effectiveEndDate=None, Relation=None, headers=None, **kwargs):
    """
    权益-修改权益-Y
    up_time=1675669374

    params: rightsName : string : 权益名称
    params: rightsId : string : 权益主键
    params: Content : string : 权益描述
    params: effectiveStartDate : string : 权益生效时间
    params: effectiveEndDate : string : 权益生效时间-结束
    params: Relation : string : 互斥关系
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败1成功
    params: msg : string : 
    params: data : string : 
    """
    _method = "POST"
    _url = "/order/rights/rightsManager/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "rightsName": rightsName,  # 权益名称
        "rightsId": rightsId,  # 权益主键
        "Content": Content,  # 权益描述
        "effectiveStartDate": effectiveStartDate,  # 权益生效时间
        "effectiveEndDate": effectiveEndDate,  # 权益生效时间-结束
        "Relation": Relation,  # 互斥关系
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rights/rightsManager/rightsById")
def order_rights_rightsmanager_rightsbyid(id=None, headers=None, **kwargs):
    """
    权益-获取权益详情-Y
    up_time=1675669384

    params: id :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败 1成功
    params: msg : string : 
    params: data : object : 
              rightsId : number : 主键
              rightsType : integer : 权益类型
              rightsName : string : 权益名称
              content : string : 权益描述
              buyAmount : string : 权益购买金额
              discountAmount : string : 权益优惠金额
              modelId : string : 车型
              orderType : string : 关联订单类型
              relation : string : 互斥关系
              status : string :  权益状态(0未生效，1已生效)
              effectiveDate : string : 权益生效时间
              createTime : string : 创建时间
              createBy : number : 创建人
              updateTime : string : 更新时间
              updateId : number : 更新人id
              delFlag : integer : 删除标识 0：否 1：是
    """
    _method = "GET"
    _url = "/order/rights/rightsManager/rightsById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "id": id,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/order/rights/rightsManager/updateStatusById")
def order_rights_rightsmanager_updatestatusbyid(rightsId=None, status=None, headers=None, **kwargs):
    """
    权益-通过id更新权益生效状态-Y
    up_time=1675669396

    params: rightsId :  : 
    params: status :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 0失败1成功
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "GET"
    _url = "/order/rights/rightsManager/updateStatusById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "rightsId": rightsId,
        "status": status,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.order.sqls_order_freeorder import SqlsOrderFreeorder


class AssertsOrderFreeorder(SqlsOrderFreeorder):
    @allure.step(title="接口返回结果校验")
    def assert_order_freeorder_download(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_freeorder_download(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userPolicyCode", "createTime", "regisTimeBegin", "avatarUrl", "userName", "privacyPolicyCode", "regisTimeEnd", "channel", "freeOrderId", "cityId", "mobile", "provinceId", "cityName", "modelId", "channelName", "nickName", "provinceName"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_messagemanager import SqlsContentMessagemanager


class AssertsContentMessagemanager(SqlsContentMessagemanager):
    @allure.step(title="接口返回结果校验")
    def assert_content_messagemanager_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_messagemanager_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["pStartTime", "userId", "cStartTime", "authId", "endTime", "messageId", "pEndTime", "cEndTime", "content", "status", "beginTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_messagemanager_getmessageinfo_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_messagemanager_getmessageinfo_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["messageId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_messagemanager_messagetop(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_messagemanager_messagetop(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topFlag", "messageIds"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_messagemanager_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_messagemanager_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["imageUrl", "sendScope", "messageId", "param", "checkPublish", "sourceType", "publishType", "checkStatus", "content", "publishTime", "type"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_messagemanager_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_messagemanager_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["imageUrl", "sendScope", "userMobiles", "messageId", "param", "checkPublish", "sourceType", "checkStatus", "content", "type"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_messagemanager_publishupdate(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_messagemanager_publishupdate(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["publishStatus", "messageIds"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_messagemanager_statusupdate(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_messagemanager_statusupdate(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["checkStatus", "messageIds"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.order.sqls_order_order import SqlsOrderOrder


class AssertsOrderOrder(SqlsOrderOrder):
    @allure.step(title="接口返回结果校验")
    def assert_order_order_orderdetail(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_order_orderdetail(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "orderStatus", "pageNum", "total", "orderId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_order_finish(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_order_finish(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_order_order_refundreject(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_order_order_refundreject(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"




from service.app_a.funs.goods.funs_goods_carmodel import FunsGoodsCarmodel
from service.app_a.funs.goods.funs_goods_configure import FunsGoodsConfigure
from service.app_a.funs.goods.funs_goods_ordermain import FunsGoodsOrdermain
from service.app_a.funs.goods.funs_goods_testdrive import FunsGoodsTestdrive
from service.app_a.funs.goods.funs_goods_area import FunsGoodsArea


class FunsGoods(FunsGoodsCarmodel, FunsGoodsConfigure, FunsGoodsOrdermain, FunsGoodsTestdrive, FunsGoodsArea):
    pass




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/common/user4C/queryActivitySource")
def common_user4c_queryactivitysource( headers=None, **kwargs):
    """
    用户列表-活动来源-Y
    up_time=1675305114

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              id : string : 例：抖音
              name : string : 例：抖音
    """
    _method = "GET"
    _url = "/common/user4C/queryActivitySource"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/page")
def common_user4c_page(userId=None, lastLoginTimeEnd=None, size=None, createTimeStart=None, nickName=None, memberSystemSource=None, userSystemSource=None, createTimeEnd=None, regisTimeEnd=None, lastLoginTimeStart=None, mobile=None, ownerFlag=None, regisTimeBegin=None, activitySource=None, status=None, current=None, type=None, headers=None, **kwargs):
    """
    用户列表-查询-Y
    up_time=1675318775

    params: userId :  : 用户Id
    params: mobile :  : 用户手机号码
    params: nickName :  : 用户昵称
    params: status :  : 会员状态 0：禁用 1：启用
    params: type :  : 用户类型 0：注册 1：非注册
    params: memberSystemSource :  : 会员来源系统： 1：APP、2：微信小程序、3：官网、4：H5
    params: size :  : 每页数据数
    params: current :  : 当前页数
    params: userSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
    params: activitySource :  : 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
    params: ownerFlag :  : 1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
    params: createTimeStart :  : 用户创建开始时间
    params: createTimeEnd :  : 用户创建结束时间
    params: regisTimeBegin :  : 会员注册开始时间
    params: regisTimeEnd :  : 会员注册结束时间
    params: lastLoginTimeStart :  : 用户最近登录开始时间
    params: lastLoginTimeEnd :  : 用户最近登录结束时间
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0：成功 1：失败
    params: msg : string :  信息 
    params: data : object : 数据
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/common/user4C/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户Id
        "mobile": mobile,  # 用户手机号码
        "nickName": nickName,  # 用户昵称
        "status": status,  # 会员状态 0：禁用 1：启用
        "type": type,  # 用户类型 0：注册 1：非注册
        "memberSystemSource": memberSystemSource,  # 会员来源系统： 1：APP、2：微信小程序、3：官网、4：H5
        "size": size,  # 每页数据数
        "current": current,  # 当前页数
        "userSystemSource": userSystemSource,  # 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
        "activitySource": activitySource,  # 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
        "ownerFlag": ownerFlag,  # 1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
        "createTimeStart": createTimeStart,  # 用户创建开始时间
        "createTimeEnd": createTimeEnd,  # 用户创建结束时间
        "regisTimeBegin": regisTimeBegin,  # 会员注册开始时间
        "regisTimeEnd": regisTimeEnd,  # 会员注册结束时间
        "lastLoginTimeStart": lastLoginTimeStart,  # 用户最近登录开始时间
        "lastLoginTimeEnd": lastLoginTimeEnd,  # 用户最近登录结束时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/vehicleInfo")
def common_user4c_vehicleinfo(size=None, userId=None, mobile=None, current=None, headers=None, **kwargs):
    """
    用户列表-详情-车辆信息-Y
    up_time=1675319192

    params: userId :  : 用户ID
    params: mobile :  : 用户手机号码
    params: current :  : 页码
    params: size :  : 每页大小
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0：成功 1：失败
    params: msg : string : 信息
    params: data : object : 数据
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/common/user4C/vehicleInfo"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
        "mobile": mobile,  # 用户手机号码
        "current": current,  # 页码
        "size": size,  # 每页大小
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/getById")
def common_user4c_getbyid(userId=None, headers=None, **kwargs):
    """
    用户中心-用户基本信息-Y
    up_time=1677207988

    params: userId :  : 用户主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0：成功 1：失败
    params: msg : string : 信息
    params: data : object : 数据
              userId : number : 用户Id
              avatarUrl : string : 头像URL
              realName : string : 真实姓名
              mobile : string : 用户号码
              sex : integer : 用户性别 用户性别 1:男生 2:女生 3:保密
              nickName : string : 昵称
              carAddress : string : 用车省市
              birthday : string : 用户生日
              explain : string : 说明简介
              owner : string : 车主身份
              wxOpenId : string : 微信openID
              appleId : string : appleID
              registerType : string : 注册来源
              userSystemSource : string : 用户来源系统
              externalCreateTime : string : 用户创建时间
              memberSystemSource : string : 会员来源系统
              createTime : string : 会员注册时间
              userTypeName : string : 0:注册 1 非注册   用户类型
              activitySource : string : 用户活动来源
              lastLoginTime : string : 最近登陆时间
              lastLoginClient : string : 最近登陆端
              historyLoginClient : string : 历史登陆端
              userPolicyCode : string : 用户协议版本号
              privacyPolicyCode : string : 隐私协议版本号
              userPolicySignTime : string : 用户协议签订时间
              privacyPolicySignTime : string : 隐私协议签订时间
              status : integer : 用户状态 是否可用 0：禁用 1：启用 - 列表页展示
              county : string : 用户区县
              city : string : 用户城市
              province : string : 用户省份
              usableQty : integer : 可用积分
              freezeQty : integer : 冻结积分
    """
    _method = "GET"
    _url = "/common/user4C/getById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/updateUser")
def common_user4c_updateuser(userId=None, headers=None, **kwargs):
    """
    用户中心-编辑官方账号-Y
    up_time=1675319403

    params: userId : text : Long；用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0 成功 1 失败
    params: msg : string : 信息
    params: data : boolean : 状态
    """
    _method = "POST"
    _url = "/common/user4C/updateUser"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # Long；用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/download")
def common_user4c_download(userId=None, lastLoginTimeEnd=None, userIds=None, createTimeStart=None, nickName=None, memberSystemSource=None, userSystemSource=None, createTimeEnd=None, regisTimeEnd=None, lastLoginTimeStart=None, mobile=None, downloadType=None, ownerFlag=None, regisTimeBegin=None, activitySource=None, status=None, type=None, headers=None, **kwargs):
    """
    用户列表-导出-Y
    up_time=1675148564

    params: userId :  : 用户Id
    params: mobile :  : 用户手机号
    params: nickName :  : 用户昵称
    params: status :  : 会员状态 0：禁用 1：启用
    params: type :  : 用户类型 0：注册 1：非注册
    params: memberSystemSource :  : 会员来源系统： 1：APP、2：微信小程序、3：官网、4：H5
    params: userSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
    params: activitySource :  : 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
    params: ownerFlag :  : 1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
    params: createTimeStart :  : 用户创建开始时间
    params: createTimeEnd :  : 用户创建结束时间
    params: regisTimeBegin :  : 会员注册开始时间
    params: regisTimeEnd :  : 会员注册结束时间
    params: lastLoginTimeStart :  : 会员最近登录开始时间
    params: lastLoginTimeEnd :  : 会员最近登录结束时间
    params: downloadType :  : 导出类型 1: 条件导出 2: 批量导出
    params: userIds :  : 导出用户主键集合，downloadType=2为必填
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/common/user4C/download"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户Id
        "mobile": mobile,  # 用户手机号
        "nickName": nickName,  # 用户昵称
        "status": status,  # 会员状态 0：禁用 1：启用
        "type": type,  # 用户类型 0：注册 1：非注册
        "memberSystemSource": memberSystemSource,  # 会员来源系统： 1：APP、2：微信小程序、3：官网、4：H5
        "userSystemSource": userSystemSource,  # 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
        "activitySource": activitySource,  # 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
        "ownerFlag": ownerFlag,  # 1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
        "createTimeStart": createTimeStart,  # 用户创建开始时间
        "createTimeEnd": createTimeEnd,  # 用户创建结束时间
        "regisTimeBegin": regisTimeBegin,  # 会员注册开始时间
        "regisTimeEnd": regisTimeEnd,  # 会员注册结束时间
        "lastLoginTimeStart": lastLoginTimeStart,  # 会员最近登录开始时间
        "lastLoginTimeEnd": lastLoginTimeEnd,  # 会员最近登录结束时间
        "downloadType": downloadType,  # 导出类型 1: 条件导出 2: 批量导出
        "userIds": userIds,  # 导出用户主键集合，downloadType=2为必填
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/beforePointsExport")
def common_user4c_beforepointsexport(userId=None, lastLoginTimeEnd=None, userIds=None, createTimeStart=None, nickName=None, memberSystemSource=None, userSystemSource=None, createTimeEnd=None, regisTimeEnd=None, lastLoginTimeStart=None, mobile=None, downloadType=None, ownerFlag=None, regisTimeBegin=None, activitySource=None, status=None, type=None, headers=None, **kwargs):
    """
    用户列表-导出前置判断-Y
    up_time=1675306476

    params: userId :  : 用户Id
    params: mobile :  : 用户手机号
    params: nickName :  : 用户昵称
    params: status :  : 账号状态 0：禁用 1：启用
    params: type :  : 用户类型 0：注册 1：非注册
    params: memberSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5
    params: userSystemSource :  : 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
    params: activitySource :  : 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
    params: ownerFlag :  :  1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
    params: createTimeStart :  : 用户创建开始时间
    params: createTimeEnd :  : 用户创建结束时间
    params: regisTimeBegin :  : 会员注册开始时间
    params: regisTimeEnd :  : 会员注册结束时间
    params: lastLoginTimeStart :  : 会员最近登录开始时间
    params: lastLoginTimeEnd :  : 会员最近登录结束时间
    params: downloadType :  : 1：条件导出 2：批量导出
    params: userIds :  : 用户Id downloadType为2时必填
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0：成功 1：失败
    params: msg : string : 描述
    params: data : boolean : true 调用参考导出条件搜索用户列表接口
    """
    _method = "GET"
    _url = "/common/user4C/beforePointsExport"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户Id
        "mobile": mobile,  # 用户手机号
        "nickName": nickName,  # 用户昵称
        "status": status,  # 账号状态 0：禁用 1：启用
        "type": type,  # 用户类型 0：注册 1：非注册
        "memberSystemSource": memberSystemSource,  # 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5
        "userSystemSource": userSystemSource,  # 用户来源系统： 1：APP、2：微信小程序、3：官网、4：H5、5：SCRM、6：DMS
        "activitySource": activitySource,  # 用户活动来源 0：0元购、1：预约试驾、2：蓝牙共享车主、3：邀请好友、4：SCRM、5：DMS
        "ownerFlag": ownerFlag,  #  1：车主、2：使用人、3：共享车主、4：非车主；可多个标签叠加
        "createTimeStart": createTimeStart,  # 用户创建开始时间
        "createTimeEnd": createTimeEnd,  # 用户创建结束时间
        "regisTimeBegin": regisTimeBegin,  # 会员注册开始时间
        "regisTimeEnd": regisTimeEnd,  # 会员注册结束时间
        "lastLoginTimeStart": lastLoginTimeStart,  # 会员最近登录开始时间
        "lastLoginTimeEnd": lastLoginTimeEnd,  # 会员最近登录结束时间
        "downloadType": downloadType,  # 1：条件导出 2：批量导出
        "userIds": userIds,  # 用户Id downloadType为2时必填
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/insert")
def common_user4c_insert(explain=None, avatarUrl=None, nickName=None, headers=None, **kwargs):
    """
    用户列表-新增-Y
    up_time=1675319481

    params: avatarUrl : text : String；图片地址
    params: explain : text : String；简介
    params: nickName : text : String；昵称
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0：成功 1：失败
    params: msg : string : 信息 
    params: data : boolean : TRUE：成功 FALSE：失败
    """
    _method = "POST"
    _url = "/common/user4C/insert"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "avatarUrl": avatarUrl,  # String；图片地址
        "explain": explain,  # String；简介
        "nickName": nickName,  # String；昵称
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/editStatus")
def common_user4c_editstatus(userId=None, status=None, headers=None, **kwargs):
    """
    用户中心-禁用/启用用户-Y
    up_time=1675320747

    params: userId : text : 
    params: status : number : 是否启用0：禁用 1：启用
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/common/user4C/editStatus"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,
        "status": status,  # 是否启用0：禁用 1：启用
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/auditExport")
def common_user4c_auditexport(userId=None, userIds=None, registerType=None, userLabel=None, phone=None, userType=None, downloadType=None, ownerFlag=None, nickName=None, headers=None, **kwargs):
    """
    导出用户审核列表-Y
    up_time=1675308559

    params: userId :  : 用户主键
    params: phone :  : 手机号
    params: nickName :  : 昵称
    params: ownerFlag :  : 是否车主认证1：是0：否
    params: userLabel :  : 用户标签
    params: registerType :  : 用户来源
    params: userType :  : 用户类型
    params: downloadType :  : 下载类型1：根据搜索条件导出2：多选导出
    params: userIds :  : 导出用户id集合，用英文,隔开
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/common/user4C/auditExport"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户主键
        "phone": phone,  # 手机号
        "nickName": nickName,  # 昵称
        "ownerFlag": ownerFlag,  # 是否车主认证1：是0：否
        "userLabel": userLabel,  # 用户标签
        "registerType": registerType,  # 用户来源
        "userType": userType,  # 用户类型
        "downloadType": downloadType,  # 下载类型1：根据搜索条件导出2：多选导出
        "userIds": userIds,  # 导出用户id集合，用英文,隔开
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/identity")
def common_user4c_identity(userId=None, headers=None, **kwargs):
    """
    根据id查询用户身份-Y
    up_time=1675319654

    params: userId :  : 用户主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              records : object : 
    """
    _method = "GET"
    _url = "/common/user4C/identity"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/updateAudit")
def common_user4c_updateaudit(userId=None, auditType=None, headers=None, **kwargs):
    """
    更新审核状态-Y
    up_time=1675319778

    params: userId : string : 用户ID
    params: auditType : integer : 认证类型（1：注销审核单据，2：车主认证审核单据）
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0：成功 1：失败
    params: msg : string : 信息
    params: data : boolean : 状态
    """
    _method = "POST"
    _url = "/common/user4C/updateAudit"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
        "auditType": auditType,  # 认证类型（1：注销审核单据，2：车主认证审核单据）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/auditList")
def common_user4c_auditlist(userId=None, userName=None, registerType=None, pageNum=None, pageSize=None, mobile=None, checkStatus=None, nickName=None, headers=None, **kwargs):
    """
    根据用户审核状态搜索列表-Y
    up_time=1675320694

    params: userId :  : 用户id
    params: mobile :  : 手机号
    params: nickName :  : 用户昵称
    params: userName :  : 用户实名姓名
    params: registerType :  : 用户来源
    params: pageSize :  : 每页数量
    params: pageNum :  : 当前页数
    params: checkStatus :  : 状态 0-正常 1-审核中 2-通过3-审核不通过
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : object : 
              records : array : 
              auditedCount : number : 已通过数量
              auditCount : number : 待审核数量
              total : number : 
              size : number : 
              pages : number : 
              maxLimit : number : 待审核数据量
    """
    _method = "GET"
    _url = "/common/user4C/auditList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户id
        "mobile": mobile,  # 手机号
        "nickName": nickName,  # 用户昵称
        "userName": userName,  # 用户实名姓名
        "registerType": registerType,  # 用户来源
        "pageSize": pageSize,  # 每页数量
        "pageNum": pageNum,  # 当前页数
        "checkStatus": checkStatus,  # 状态 0-正常 1-审核中 2-通过3-审核不通过
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/common/user4C/getUserPoints")
def common_user4c_getuserpoints(userId=None, headers=None, **kwargs):
    """
    用户信息积分详情-？历史接口
    up_time=1676338919

    params: userId :  : 用户ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 永远成功
    params: msg : string : 信息
    params: data : object : 数据
              userPoints : object : 
              userPointsLog : array : 
    """
    _method = "GET"
    _url = "/common/user4C/getUserPoints"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/material/getMaterialList_1659319316474")
def content_material_getmateriallist_1659319316474(size=None, groupId=None, current=None, headers=None, **kwargs):
    """
    素材-根据素材组获取素材列表_copy
    up_time=1675755133

    params: groupId :  : 分组主键
    params: size :  : 每页数据数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/material/getMaterialList_1659319316474"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "groupId": groupId,  # 分组主键
        "size": size,  # 每页数据数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.goods.sqls_goods_carmodel import SqlsGoodsCarmodel


class AssertsGoodsCarmodel(SqlsGoodsCarmodel):
    @allure.step(title="接口返回结果校验")
    def assert_goods_carmodel_savemanagecarmodel(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_carmodel_savemanagecarmodel(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["carDetailType", "preToDepositEndTime", "prePrice", "sharePosters", "price", "preEndTime", "carCode", "brandName", "modelName", "modelId", "modelCode", "carName", "depositStartTime", "depositPriceContent", "depositEndTime", "carSimpleName", "prePriceContent", "status", "promptDesc", "preToDepositStartTime", "preStartTime", "version", "carDetailPics", "carDetailUrl", "prePricePosters", "sort", "configCode", "depositPrice", "posters"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_carmodel_removebyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_carmodel_removebyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["modelId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_carmodel_getcarmodelmanagebyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_carmodel_getcarmodelmanagebyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["modelId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_carmodel_getmanagecarmodel(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_carmodel_getmanagecarmodel(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["modelCode", "carName", "operator", "version", "carCode", "brandName", "modelName", "status"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_carmodel_getmodelnamelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_carmodel_getmodelnamelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_goods_carmodel_getcarnamelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_goods_carmodel_getcarnamelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/admin/guc/gucLogout")
def admin_guc_guclogout( headers=None, **kwargs):
    """
    guc登出
    up_time=1675133803

    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : object : 返回
              result : boolean : true成功
    """
    _method = "POST"
    _url = "/admin/guc/gucLogout"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/admin/guc/gucLogin")
def admin_guc_guclogin( headers=None, **kwargs):
    """
    guc登录回调
    up_time=1675133803

    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : object : 返回
              result : boolean : true成功
    """
    _method = "POST"
    _url = "/admin/guc/gucLogin"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/goods/area/getParentArea")
def goods_area_getparentarea(country=None, parentId=None, headers=None, **kwargs):
    """
    订单管理-地区下拉（930版本）-Y
    up_time=1675385800

    params: parentId :  : 父地区id（null 则省，下一级递增）
    params: country :  : all会加上全国信息
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              areaId : number : 地区id
              areaName : string : 区域名称
              areaLevel : number : 区域级别： 1  省份， 2  市， 3  区县
              parentId : integer : 父级id
              areaType : number : 0:全面解禁，1:部分解禁，2:禁行
              areaPyName : string : 中文拼音
              dealerCodeList : array : 经销商ID
              dealerCodes : ['string', 'null'] : 经销商ID
    """
    _method = "GET"
    _url = "/goods/area/getParentArea"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "parentId": parentId,  # 父地区id（null 则省，下一级递增）
        "country": country,  # all会加上全国信息
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/area/getDefaultDealer")
def goods_area_getdefaultdealer(cityCode=None, headers=None, **kwargs):
    """
    pc端查询城市默认经销商-Y
    up_time=1675389643

    params: cityCode :  : 城市编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 编码
    params: msg : string : 消息
    params: data : object : 数据
              areaIds : array : 
              dealerCode : string : 经销商编码
              dealerName : string : 经销商名称
              companyName : string : 
              companyCode : string : 
    """
    _method = "GET"
    _url = "/goods/area/getDefaultDealer"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "cityCode": cityCode,  # 城市编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/area/insertRelation")
def goods_area_insertrelation(areaIds=None, dealerCode=None, headers=None, **kwargs):
    """
    后台管理-设置默认经销商-Y
    up_time=1675389550

    params: areaIds : array : 地区集合
              type : integer : None
              description : 地区Id : None
    params: dealerCode : string : 进销商编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : true
    """
    _method = "POST"
    _url = "/goods/area/insertRelation"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "areaIds": areaIds,  # 地区集合
        "dealerCode": dealerCode,  # 进销商编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/area/getCityList")
def goods_area_getcitylist(size=None, cType=None, cName=None, pName=None, current=None, headers=None, **kwargs):
    """
    城市禁行列表查询-Y
    up_time=1675388494

    params: size :  : 当前页数量
    params: current :  : 当前页号
    params: pName :  : 省份名称
    params: cName :  : 城市名称
    params: cType :  : 城市禁行类型 0:全面解禁，1:部分解禁，2:禁行  
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/goods/area/getCityList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "size": size,  # 当前页数量
        "current": current,  # 当前页号
        "pName": pName,  # 省份名称
        "cName": cName,  # 城市名称
        "cType": cType,  # 城市禁行类型 0:全面解禁，1:部分解禁，2:禁行  
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/area/getCityById")
def goods_area_getcitybyid(cityId=None, headers=None, **kwargs):
    """
    查询禁行城市信息-Y
    up_time=1675388979

    params: cityId :  : 城市编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 编码
    params: msg : string : 消息
    params: data : object : 数据
              areaId : number : 编码
              areaName : string : 名称
              areaLevel : number : 级别
              parentId : number : 父类编码
              areaType : number : 城市禁行类型      0:全面解禁，1:部分解禁，2:禁行
              areaPyName : string : 中文拼音
    """
    _method = "GET"
    _url = "/goods/area/getCityById"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "cityId": cityId,  # 城市编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/area/getMapArea")
def goods_area_getmaparea(parentId=None, headers=None, **kwargs):
    """
    地区下拉待字母（930）-?
    up_time=1675387893

    params: parentId :  : 地区Id（省传null ，其余传areaId的值）
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              A : array : 字母
              B : array : 
              C : array : 
              F : array : 
              G : array : 
              H : array : 
              J : array : 
              L : array : 
              N : array : 
              Q : array : 
              S : array : 
              T : array : 
              X : array : 
              Y : array : 
              Z : array : 
    """
    _method = "GET"
    _url = "/goods/area/getMapArea"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "parentId": parentId,  # 地区Id（省传null ，其余传areaId的值）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/area/getCity")
def goods_area_getcity(parentId=None, headers=None, **kwargs):
    """
    城市下拉带字母（930）-？
    up_time=1675388144

    params: parentId :  : 父级ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              A : array : 字母
              B : array : 字母
              C : array : 字母
              D : array : 字母
              E : array : 字母
              F : array : 字母
              G : array : 字母
              H : array : 字母
              J : array : 字母
              K : array : 字母
              L : array : 字母
              M : array : 字母
              N : array : 字母
              P : array : 字母
              Q : array : 字母
              R : array : 字母
              S : array : 字母
              T : array : 字母
              W : array : 字母
              X : array : 字母
              Y : array : 字母
              Z : array : 字母
    """
    _method = "GET"
    _url = "/goods/area/getCity"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "parentId": parentId,  # 父级ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/goods/area/updateCityType")
def goods_area_updatecitytype(cId=None, cType=None, headers=None, **kwargs):
    """
    城市禁行状态变更-？
    up_time=1675388620

    params: cType : integer : 禁用类型
    params: cId : integer : 城市编码
    params: headers : 请求头
    ====================返回======================
    params: code : number : 编码
    params: msg : string : 消息
    params: data : boolean : true|false
    """
    _method = "POST"
    _url = "/goods/area/updateCityType"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "cType": cType,  # 禁用类型
        "cId": cId,  # 城市编码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





from service.app_a.apis import apis_content
from service.app_a.asserts.asserts_content import AssertsContent
import allure
from service.app_a.funs.content.funs_content_campmanager import FunsContentCampmanager
from service.app_a.funs.content.funs_content_activitymanager import FunsContentActivitymanager
from service.app_a.funs.content.funs_content_messagemanager import FunsContentMessagemanager
from service.app_a.funs.content.funs_content_noticemanager import FunsContentNoticemanager
from service.app_a.funs.content.funs_content_adv import FunsContentAdv
from service.app_a.funs.content.funs_content_agreement import FunsContentAgreement
from service.app_a.funs.content.funs_content_essay import FunsContentEssay
from service.app_a.funs.content.funs_content_subject import FunsContentSubject
from service.app_a.funs.content.funs_content_subjectweb import FunsContentSubjectweb
from service.app_a.funs.content.funs_content_essayweb import FunsContentEssayweb
from service.app_a.funs.content.funs_content_contentmanager import FunsContentContentmanager
from service.app_a.funs.content.funs_content_essaycomment import FunsContentEssaycomment
from service.app_a.funs.content.funs_content_commonquestion import FunsContentCommonquestion
from service.app_a.funs.content.funs_content_recruit import FunsContentRecruit
from service.app_a.funs.content.funs_content_advplace import FunsContentAdvplace
from service.app_a.funs.content.funs_content_hotcity import FunsContentHotcity
from service.app_a.funs.content.funs_content_hotsearch import FunsContentHotsearch
from service.app_a.funs.content.funs_content_material import FunsContentMaterial
from service.app_a.funs.content.funs_content_comment import FunsContentComment
from service.app_a.funs.content.funs_content_topic4c import FunsContentTopic4C
from service.app_a.funs.content.funs_content_question import FunsContentQuestion
from service.app_a.funs.content.funs_content_safecode import FunsContentSafecode


class FunsContent(FunsContentCampmanager, FunsContentActivitymanager, FunsContentMessagemanager, FunsContentNoticemanager, FunsContentAdv, AssertsContent, FunsContentAgreement, FunsContentEssay, FunsContentSubject, FunsContentSubjectweb, FunsContentEssayweb, FunsContentContentmanager, FunsContentEssaycomment, FunsContentCommonquestion, FunsContentRecruit, FunsContentAdvplace, FunsContentHotcity, FunsContentHotsearch, FunsContentMaterial, FunsContentComment, FunsContentTopic4C, FunsContentQuestion, FunsContentSafecode):
    @allure.step(title="点位内容-通过id删除点位内容-Y")
    def content_adv_(self, advId="$None$", _assert=True,  **kwargs):
        """
            url=/content/adv/{advId}
                params: advId :  :
                params: headers : 请求头
        """
        advId = self.get_value_choice(advId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content.content_adv_(**_kwargs)

        self.assert_content_adv_(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.common.asserts_common_userpointsmanage import AssertsCommonUserpointsmanage
from service.app_a.apis.common import apis_common_userpointsmanage


class FunsCommonUserpointsmanage(AssertsCommonUserpointsmanage):
    @allure.step(title="用户积分列表导出-历史接口")
    def common_userpointsmanage_userpointsexport(self, logIds="$None$", endTime="$None$", mobile="$None$", nickName="$None$", beginTime="$None$", _assert=True,  **kwargs):
        """
            url=/common/userPointsManage/userPointsExport
                params: nickName :  : 用户昵称
                params: mobile :  : 用户手机号
                params: beginTime :  : 注册时间查询范围--开始时间
                params: endTime :  : 注册时间查询范围--结束时间
                params: logIds :  : 积分明细Id，用于积分导出，如果传参表示勾选数据导出
                params: headers : 请求头
        """
        logIds = self.get_list_choice(logIds, list_or_dict=None, key="logIds")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        beginTime = self.get_list_choice(beginTime, list_or_dict=None, key="beginTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_userpointsmanage.common_userpointsmanage_userpointsexport(**_kwargs)

        self.assert_common_userpointsmanage_userpointsexport(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户积分列表查询-历史接口")
    def common_userpointsmanage_page(self, mobile="$None$", nickName="$None$", endTime="$None$", beginTime="$None$", _assert=True,  **kwargs):
        """
            url=/common/userPointsManage/page
                params: nickName :  :
                params: mobile :  :
                params: beginTime :  : 前端日期后面必须要追加 00:00:00
                params: endTime :  : 前端日期后面必须要追加 23:59:59
                params: headers : 请求头
        """
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        beginTime = self.get_list_choice(beginTime, list_or_dict=None, key="beginTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_userpointsmanage.common_userpointsmanage_page(**_kwargs)

        self.assert_common_userpointsmanage_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="用户积分手动调整-历史接口")
    def common_userpointsmanage_manualchangeuserpoints(self, userId="$None$", operatePoint="$None$", operateType="$None$", taskName="$None$", operateMark="$None$", pointChangType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/common/userPointsManage/manualChangeUserPoints
                params: operateType : string : 积分操作类型 目前只有 “增加” 一类
                params: operatePoint : integer : 操作的积分数量
                params: operateMark : string : 操作的积分备注
                params: taskName : string : 任务名称 注册 签到 消费
                params: pointChangType : number : 1--增加  2--消耗
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        operatePoint = self.get_value_choice(operatePoint, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        operateType = self.get_value_choice(operateType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        taskName = self.get_value_choice(taskName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        operateMark = self.get_value_choice(operateMark, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        pointChangType = self.get_value_choice(pointChangType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_userpointsmanage.common_userpointsmanage_manualchangeuserpoints(**_kwargs)

        self.assert_common_userpointsmanage_manualchangeuserpoints(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分导出前置判断-历史接口")
    def common_userpointsmanage_beforepointsexport(self, logIds="$None$", endTime="$None$", mobile="$None$", nickName="$None$", beginTime="$None$", _assert=True,  **kwargs):
        """
            url=/common/userPointsManage/beforePointsExport
                params: nickName :  : 用户昵称
                params: mobile :  : 用户手机号
                params: beginTime :  : 注册时间查询范围--开始时间
                params: endTime :  : 注册时间查询范围--结束时间
                params: logIds :  : 积分明细Id，用于积分导出，如果传参表示勾选数据导出
                params: headers : 请求头
        """
        logIds = self.get_list_choice(logIds, list_or_dict=None, key="logIds")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        nickName = self.get_list_choice(nickName, list_or_dict=None, key="nickName")
        beginTime = self.get_list_choice(beginTime, list_or_dict=None, key="beginTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_userpointsmanage.common_userpointsmanage_beforepointsexport(**_kwargs)

        self.assert_common_userpointsmanage_beforepointsexport(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.common.asserts_common_remoteinterfacelog import AssertsCommonRemoteinterfacelog
from service.app_a.apis.common import apis_common_remoteinterfacelog


class FunsCommonRemoteinterfacelog(AssertsCommonRemoteinterfacelog):
    @allure.step(title="查询三方日志接口-Y")
    def common_remoteinterfacelog_getlogpage(self, size=10, userName="$None$", endTime="$None$", interfaceType="$None$", mobile="$None$", startTime="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/common/remoteinterfacelog/getLogPage
                params: interfaceType :  : 日志类型（1.支付日志  2.退款日志  3.换电日志）
                params: startTime :  : 开始时间
                params: endTime :  : 结束时间
                params: userName :  : 用户昵称
                params: mobile :  : 手机号
                params: size :  : 每页条数
                params: current :  : 当前页
                params: headers : 请求头
        """
        userName = self.get_list_choice(userName, list_or_dict=None, key="userName")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        interfaceType = self.get_list_choice(interfaceType, list_or_dict=None, key="interfaceType")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_common_remoteinterfacelog.common_remoteinterfacelog_getlogpage(**_kwargs)

        self.assert_common_remoteinterfacelog_getlogpage(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


